#[non_exhaustive]pub enum ReaderError {
NoArray,
InvalidIndex,
NoObject,
InvalidMember,
InvalidNode,
NoValue,
InvalidType,
}Expand description
Error codes for JSON_READER_ERROR.
This enumeration can be extended at later date
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoArray
No array found at the current position
InvalidIndex
Index out of bounds
NoObject
No object found at the current position
InvalidMember
Member not found
InvalidNode
No valid node found at the current position
NoValue
The node at the current position does not hold a value
InvalidType
The node at the current position does not hold a value of the desired type