Module functions

Module functions 

Functions

boxed_can_deserialize
Checks whether it is possible to deserialize a GBoxed of type gboxed_type from a Node of type node_type.
boxed_can_serialize
Checks whether it is possible to serialize a GBoxed of type gboxed_type into a Node.
from_stringv1_2
Parses the given string and returns the corresponding JSON tree.
gobject_deserialize
Creates a new GObject instance of the given type, and constructs it using the members of the object in the given node.
gobject_from_data
Deserializes a JSON data stream and creates an instance of the given type.
gobject_serialize
Creates a JSON tree representing the passed object instance.
gobject_to_data
Serializes a GObject instance into a JSON data stream, iterating recursively over each property.
gvariant_deserialize
Converts a JSON data structure to a GVariant.
gvariant_deserialize_data
Converts a JSON string to a GVariant value.
gvariant_serialize
Converts variant to a JSON tree.
gvariant_serialize_data
Converts @variant to its JSON encoded string representation.
string_comparev1_2
string_equalv1_2
string_hashv1_2
to_stringv1_2
Generates a stringified JSON representation of the contents of the given node.