from_string

Function from_string 

pub fn from_string(str: &str) -> Result<Option<Node>, Error>
Available on crate feature v1_2 only.
Parses the given string and returns the corresponding JSON tree.

If the string is empty, this function will return NULL.

In case of parsing error, this function returns NULL and sets the error appropriately.

str

a valid UTF-8 string containing JSON data

Returns

the root node of the JSON tree