gobject_deserialize

Function gobject_deserialize 

pub fn gobject_deserialize(gtype: Type, node: &Node) -> Object
Creates a new GObject instance of the given type, and constructs it using the members of the object in the given node.

gtype

the type of the object to create

node

a node of type JSON_NODE_OBJECT describing the object instance for the given type

Returns

The newly created instance