Array

Struct Array 

pub struct Array { /* private fields */ }
JsonArray is the representation of the array type inside JSON.

A JsonArray contains Node elements, which may contain fundamental types, other arrays or objects.

Since arrays can be arbitrarily big, copying them can be expensive; for this reason, they are reference counted. You can control the lifetime of a JsonArray using Json::Array::ref() and Json::Array::unref().

To append an element, use add_element().

To extract an element at a given index, use element().

To retrieve the entire array in list form, use elements().

To retrieve the length of the array, use length().

GLib type: Shared boxed type with reference counted clone semantics.

Implementations

Source

impl Array

pub fn as_ptr(&self) -> *mut JsonArray

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow(ptr: &*mut JsonArray) -> &Self

Borrows the underlying C value.

Source

impl Array

pub fn new() -> Array

Creates a new array.

Returns

the newly created array

pub fn sized_new(n_elements: u32) -> Array

Creates a new array with n_elements slots already allocated.

n_elements

number of slots to pre-allocate

Returns

the newly created array

pub fn add_array_element(&self, value: Option<Array>)

Conveniently adds an array element into an array.

If value is NULL, a null element will be added instead.

See also: add_element(), Node::take_array()

value

the array to add

pub fn add_boolean_element(&self, value: bool)

Conveniently adds the given boolean value into an array.

See also: add_element(), Node::set_boolean()

value

the boolean value to add

pub fn add_double_element(&self, value: f64)

Conveniently adds the given floating point value into an array.

See also: add_element(), Node::set_double()

value

the floating point value to add

pub fn add_element(&self, node: Node)

Appends the given node inside an array.

node

the element to add

pub fn add_int_element(&self, value: i64)

Conveniently adds the given integer value into an array.

See also: add_element(), Node::set_int()

value

the integer value to add

pub fn add_null_element(&self)

Conveniently adds a null element into an array

See also: add_element(), JSON_NODE_NULL

pub fn add_object_element(&self, value: Option<Object>)

Conveniently adds an object into an array.

If value is NULL, a null element will be added instead.

See also: add_element(), Node::take_object()

value

the object to add

pub fn add_string_element(&self, value: &str)

Conveniently adds the given string value into an array.

See also: add_element(), Node::set_string()

value

the string value to add

pub fn dup_element(&self, index_: u32) -> Node

Retrieves a copy of the element at the given position in the array.

index_

the index of the element to retrieve

Returns

a copy of the element at the given position

pub fn foreach_element<P: FnMut(&Array, u32, &Node)>(&self, func: P)

Iterates over all elements of an array, and calls a function on each one of them.

It is safe to change the value of an element of the array while iterating over it, but it is not safe to add or remove elements from the array.

func

the function to be called on each element

pub fn array_element(&self, index_: u32) -> Array

Conveniently retrieves the array at the given position inside an array.

See also: element(), Node::array()

index_

the index of the element to retrieve

Returns

the array

pub fn is_boolean_element(&self, index_: u32) -> bool

Conveniently retrieves the boolean value of the element at the given position inside an array.

See also: element(), Node::is_boolean()

index_

the index of the element to retrieve

Returns

the boolean value

pub fn double_element(&self, index_: u32) -> f64

Conveniently retrieves the floating point value of the element at the given position inside an array.

See also: element(), Node::double()

index_

the index of the element to retrieve

Returns

the floating point value

pub fn element(&self, index_: u32) -> Node

Retrieves the element at the given position in the array.

index_

the index of the element to retrieve

Returns

the element at the given position

pub fn elements(&self) -> Vec<Node>

Retrieves all the elements of an array as a list of nodes.

Returns

the elements of the array

pub fn int_element(&self, index_: u32) -> i64

Conveniently retrieves the integer value of the element at the given position inside an array.

See also: element(), Node::int()

index_

the index of the element to retrieve

Returns

the integer value

pub fn length(&self) -> u32

Retrieves the length of the given array

Returns

the length of the array

pub fn is_null_element(&self, index_: u32) -> bool

Conveniently checks whether the element at the given position inside the array contains a null value.

See also: element(), Node::is_null()

index_

the index of the element to retrieve

Returns

TRUE if the element is null

pub fn object_element(&self, index_: u32) -> Object

Conveniently retrieves the object at the given position inside an array.

See also: element(), Node::object()

index_

the index of the element to retrieve

Returns

the object

pub fn string_element(&self, index_: u32) -> GString

Conveniently retrieves the string value of the element at the given position inside an array.

See also: element(), Node::string()

index_

the index of the element to retrieve

Returns

the string value

pub fn is_immutable(&self) -> bool

Available on crate feature v1_2 only.

Check whether the given array has been marked as immutable by calling seal() on it.

Returns

true if the array is immutable

pub fn remove_element(&self, index_: u32)

Removes the element at the given position inside an array.

This function will release the reference held on the element.

index_

the position of the element to be removed

pub fn seal(&self)

Available on crate feature v1_2 only.

Seals the given array, making it immutable to further changes.

This function will recursively seal all elements in the array too.

If the array is already immutable, this is a no-op.