Object

Struct Object 

pub struct Object { /* private fields */ }
JsonObject is the representation of the object type inside JSON.

A JsonObject contains Node “members”, which may contain fundamental types, arrays or other objects; each member of an object is accessed using a unique string, or “name”.

Since objects can be arbitrarily big, copying them can be expensive; for this reason they are reference counted. You can control the lifetime of a JsonObject using Json::Object::ref() and Json::Object::unref().

To add or overwrite a member with a given name, use set_member().

To extract a member with a given name, use member().

To retrieve the list of members, use members().

To retrieve the size of the object (that is, the number of members it has), use size().

GLib type: Shared boxed type with reference counted clone semantics.

Implementations

Source

impl Object

pub fn as_ptr(&self) -> *mut JsonObject

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow(ptr: &*mut JsonObject) -> &Self

Borrows the underlying C value.

Source

impl Object

pub fn new() -> Object

Creates a new object.

Returns

the newly created object

pub fn dup_member(&self, member_name: &str) -> Option<Node>

Retrieves a copy of the value of the given member inside an object.

member_name

the name of the JSON object member to access

Returns

a copy of the value for the requested object member

pub fn foreach_member<P: FnMut(&Object, &str, &Node)>(&self, func: P)

Iterates over all members of @self and calls @func on each one of them.

It is safe to change the value of a member of the oobject from within the iterator function, but it is not safe to add or remove members from the object.

The order in which the object members are iterated is the insertion order.

func

the function to be called on each member

pub fn array_member(&self, member_name: &str) -> Option<Array>

Convenience function that retrieves the array stored in @member_name of @self. It is an error to specify a @member_name which does not exist or which holds a non-null, non-array value.

If @member_name contains null, then this function will return NULL.

See also: member(), has_member()

member_name

the name of the member

Returns

the array inside the object’s member

pub fn is_boolean_member(&self, member_name: &str) -> bool

Convenience function that retrieves the boolean value stored in @member_name of @self. It is an error to specify a @member_name which does not exist or which holds a non-scalar, non-null value.

See also: [is_boolean_member_with_default()][Self::is_boolean_member_with_default()], member(), has_member()

member_name

the name of the member

Returns

the boolean value of the object’s member

pub fn double_member(&self, member_name: &str) -> f64

Convenience function that retrieves the floating point value stored in @member_name of @self. It is an error to specify a @member_name which does not exist or which holds a non-scalar, non-null value.

See also: [double_member_with_default()][Self::double_member_with_default()], member(), has_member()

member_name

the name of the member

Returns

the floating point value of the object’s member

pub fn int_member(&self, member_name: &str) -> i64

Convenience function that retrieves the integer value stored in @member_name of @self. It is an error to specify a @member_name which does not exist or which holds a non-scalar, non-null value.

See also: [int_member_with_default()][Self::int_member_with_default()], member(), has_member()

member_name

the name of the object member

Returns

the integer value of the object’s member

pub fn member(&self, member_name: &str) -> Option<Node>

Retrieves the value of the given member inside an object.

member_name

the name of the JSON object member to access

Returns

the value for the requested object member

pub fn members(&self) -> Vec<GString>

Retrieves all the names of the members of an object.

You can obtain the value for each member by iterating the returned list and calling member().

Returns

the member names of the object

pub fn is_null_member(&self, member_name: &str) -> bool

Convenience function that checks whether the value stored in @member_name of @self is null. It is an error to specify a @member_name which does not exist.

See also: member(), has_member()

member_name

the name of the member

Returns

TRUE if the value is null

pub fn object_member(&self, member_name: &str) -> Option<Object>

Convenience function that retrieves the object stored in @member_name of @self. It is an error to specify a @member_name which does not exist or which holds a non-null, non-object value.

If @member_name contains null, then this function will return NULL.

See also: member(), has_member()

member_name

the name of the member

Returns

the object inside the object’s member

pub fn size(&self) -> u32

Retrieves the number of members of a JSON object.

Returns

the number of members

pub fn string_member(&self, member_name: &str) -> GString

Convenience function that retrieves the string value stored in @member_name of @self. It is an error to specify a @member_name that does not exist or which holds a non-scalar, non-null value.

See also: [string_member_with_default()][Self::string_member_with_default()], member(), has_member()

member_name

the name of the member

Returns

the string value of the object’s member

pub fn values(&self) -> Vec<Node>

Retrieves all the values of the members of an object.

Returns

the member values of the object

pub fn has_member(&self, member_name: &str) -> bool

Checks whether @self has a member named @member_name.

member_name

the name of a JSON object member

Returns

TRUE if the JSON object has the requested member

pub fn is_immutable(&self) -> bool

Available on crate feature v1_2 only.

Checks whether the given object has been marked as immutable by calling seal() on it.

Returns

TRUE if the object is immutable

pub fn remove_member(&self, member_name: &str)

Removes @member_name from @self, freeing its allocated resources.

member_name

the name of the member to remove

pub fn seal(&self)

Available on crate feature v1_2 only.

Seals the object, making it immutable to further changes.

This function will recursively seal all members of the object too.

If the object is already immutable, this is a no-op.

pub fn set_array_member(&self, member_name: &str, value: Array)

Convenience function for setting an object member with an array value.

See also: set_member(), Node::take_array()

member_name

the name of the member

value

the value of the member

pub fn set_boolean_member(&self, member_name: &str, value: bool)

Convenience function for setting an object member with a boolean value.

See also: set_member(), Node::init_boolean()

member_name

the name of the member

value

the value of the member

pub fn set_double_member(&self, member_name: &str, value: f64)

Convenience function for setting an object member with a floating point value.

See also: set_member(), Node::init_double()

member_name

the name of the member

value

the value of the member

pub fn set_int_member(&self, member_name: &str, value: i64)

Convenience function for setting an object member with an integer value.

See also: set_member(), Node::init_int()

member_name

the name of the member

value

the value of the member

pub fn set_member(&self, member_name: &str, node: Node)

Sets the value of a member inside an object.

If the object does not have a member with the given name, a new member is created.

If the object already has a member with the given name, the current value is overwritten with the new.

member_name

the name of the member

node

the value of the member

pub fn set_null_member(&self, member_name: &str)

Convenience function for setting an object member with a null value.

See also: set_member(), Node::init_null()

member_name

the name of the member

pub fn set_object_member(&self, member_name: &str, value: Object)

Convenience function for setting an object member with an object value.

See also: set_member(), Node::take_object()

member_name

the name of the member

value

the value of the member

pub fn set_string_member(&self, member_name: &str, value: &str)

Convenience function for setting an object member with a string value.

See also: set_member(), Node::init_string()

member_name

the name of the member

value

the value of the member