Skip to main contentCrate json_glib
Source - functions
- prelude
- Array
JsonArray is the representation of the array type inside JSON.- Builder
JsonBuilder provides an object for generating a JSON tree.- Generator
JsonGenerator provides an object for generating a JSON data stream
from a tree of Node instances, and put it into a buffer
or a file.- Node
- A generic container of JSON data types.
- Object
JsonObject is the representation of the object type inside JSON.- Parser
JsonParser provides an object for parsing a JSON data stream, either
inside a file or inside a static buffer.- Path
JsonPath is a simple class implementing the JSONPath syntax for extracting
data out of a JSON tree.- Reader
JsonReader provides a simple, cursor-based API for parsing a JSON DOM.- Serializable
JsonSerializable is an interface for controlling the serialization
and deserialization of GObject classes.
- NodeType
- Indicates the content of a node.
- ParserError
- Error codes for
JSON_PARSER_ERROR. - PathError
- Error codes for
JSON_PATH_ERROR. - ReaderError
- Error codes for
JSON_READER_ERROR.
- VERSION_S
- The version of JSON-GLib, encoded as a string, useful for printing and
concatenation.