Functions
- boxed_
can_ deserialize - Checks whether it is possible to deserialize a
GBoxedof typegboxed_typefrom aNodeof typenode_type. - boxed_
can_ serialize - Checks whether it is possible to serialize a
GBoxedof typegboxed_typeinto aNode. - from_
string v1_2 - Parses the given string and returns the corresponding JSON tree.
- gobject_
deserialize - Creates a new
GObjectinstance of the given type, and constructs it using the members of the object in the given node. - gobject_
from_ data - Deserializes a JSON data stream and creates an instance of the given type.
- gobject_
serialize - Creates a JSON tree representing the passed object instance.
- gobject_
to_ data - Serializes a
GObjectinstance into a JSON data stream, iterating recursively over each property. - gvariant_
deserialize - Converts a JSON data structure to a
GVariant. - gvariant_
deserialize_ data - Converts a JSON string to a
GVariantvalue. - gvariant_
serialize - Converts
variantto a JSON tree. - gvariant_
serialize_ data - Converts @variant to its JSON encoded string representation.
- string_
compare v1_2 - string_
equal v1_2 - string_
hash v1_2 - to_
string v1_2 - Generates a stringified JSON representation of the contents of
the given
node.