pub fn gobject_from_data(
gtype: Type,
data: &str,
) -> Result<Option<Object>, Error>Expand description
Deserializes a JSON data stream and creates an instance of the given type.
If the type implements the Serializable interface, it will
be asked to deserialize all the JSON members into their respective properties;
otherwise, the default implementation will be used to translate the
compatible JSON native types.
Note: the JSON data stream must be an object
gtype
the type of the object to construct
data
a JSON data stream
length
length of the data stream, or -1 if it is NUL-terminated
Returns
a new object instance of the given type